run

Function run 

pub async fn run(
    pool: &AnyPool,
    backend: DbBackend,
    sets: &[MigrationSet],
) -> CoreResult<()>
Applies every pending migration across the given sets, in listed order and, within a set, in declared order. Each migration runs in its own transaction.