pub async fn rollback(
pool: &AnyPool,
backend: DbBackend,
set: &MigrationSet,
steps: usize,
) -> CoreResult<()>Expand description
Reverses the last steps applied migrations of one module, most recent
first. An irreversible migration in the way stops the rollback.